package org.greenstone.gsdl3.gs3build.collection;

import java.io.PrintWriter;

import java.util.List;

import org.greenstone.gsdl3.gs3build.metadata.METSDescriptive;

import org.greenstone.gsdl3.gs3build.doctypes.DocumentID;

/**
 *  A class to consolidate the metadata assigned to the documents of a collection
 *  as per the extension to Greenstone 2 done by George Buchanan.
 */

public class CollectionMetadata
{ METSDescriptive metadata;
	
  public CollectionMetadata()
  { this.metadata = new METSDescriptive("CM0", "collection");
  }

  /**
   *  Accrue the metadata assigned to a particular document
   *
   *  @param <code>DocumentID</code> the document identifier
   *  @param <code>String</code> the namespace of the metadata
   *  @param <code>String</code> the field of metadata
   *  @param <code>String</code> the actual value assigned
   */
  public void addDocumentMetadata(DocumentID documentID, String namespace, String field, String value)
  { // we don't presently use the document ID in this member function
    this.metadata.addMetadata(namespace, field, value);
  }

  /**
   *  Set the metadata stored on a given metadata item - any other values are
   *  destroyed.
   *
   *  @param <code>String</code> the namespace
   *  @param <code>String</code> the label of the metadata
   *  @param <code>String</code> the actual value assigned
   */
  public void setCollectionMetadata(String namespace, String label, String value)
  { this.metadata.setMetadata(namespace, label, value);
  }

  /**
   *  Get the metadata stored on a given metadata item
   *
   *  @param <code>String</code> the namespace
   *  @param <code>String</code> the label of the metadata
   */
  public List getCollectionMetadata(String namespace, String label)
  { return this.metadata.getMetadata(namespace, label);
  }

  /**
   *  Write the collection metadata
   *
   *  TODO: dummy function - complete
   */
  public boolean write(PrintWriter writer)
  { return false;
  }
}
